@@ -1,4 +1,8 @@
 #!/bin/bash
+#
+#set -x
+#set -e
+#set -o
 
 while getopts q:a:o:t:x:d:s:l: flag
 do
@@ -15,6 +19,7 @@ do
 done
 
 align="${align:-noalign}"
+data_type="${data_type:-mixed}"
 # check if data type input is valid
 valid_data="16s_full_length 16s_v4_100 16s_v4_150 16s_v3_v4 mixed"
 #contains() {
@@ -57,7 +62,9 @@ then
     export TMPDIR=/scratch/$USER/job_$SLURM_JOB_ID
   else
 #    echo "temporary file stores to $out_dir"
-    export TMPDIR=${out_dir}
+    TMPDIR=$(mktemp -d)
+    mkdir -p ${TMPDIR}
+    export TMPDIR=${TMPDIR}
   fi
   tmpdir=`mktemp -d -t 'depp-tmp-XXXXXXXXXX'`
   # check if the directory is created
@@ -76,7 +83,7 @@ then
     # split query sequences into multiple files (/tmp directory)
     for i in ${tmpdir}/query_seq/*.fa;
     do
-      upptmpdir=`mktemp -d -t 'upp-tmp-XXXXXXXXXX'`
+      upptmpdir=`mktemp -d -t 'upp'`
       # check if the directory is created
       if [[ ! "$tmpdir" || ! -d "$tmpdir" ]]; then
         echo "Could not create temp dir"
@@ -98,15 +105,9 @@ then
         mkdir ${upptmpdir}/tmp_result
         grep ">" ${i} | sed "s/^>//g" | sort > ${upptmpdir}/tmp_result/query_ids.txt
         upp_c=${cores}
-      #  awk "/^>/ {n++} n>8000 {exit} {print}" ${accessory_dir}/${data_type}_a.fasta > ${i}.backbone
-        python -c \
-        "from sepp.exhaustive_upp import main
-if __name__ == '__main__':
-  main()
-" -s ${i}  -a ${accessory_dir}/${dt}_ao.fasta  -t ${accessory_dir}/${dt}.nwk  -A 200 -d ${upptmpdir}/tmp_result -x $upp_c -p ${upptmpdir}/tmp 1>${tmpdir}/upp-out.log 2>>${out_dir}/${dt}_upp.log
-#        run_upp.py -s ${i} -a ${accessory_dir}/${dt}_ao.fasta -t ${accessory_dir}/${dt}.nwk -A 200 -d ${upptmpdir}/tmp_result -x $upp_c -p ${upptmpdir}/tmp 1>${tmpdir}/upp-out.log 2>>${out_dir}/${dt}_upp.log
-  #      grep -w -A 1 -f ${upptmpdir}/xtmp_result/query_ids.txt ${upptmpdir}/tmp_result/output_alignment_masked.fasta --no-group-separator > ${upptmpdir}/aligned/${cnt}.fa
-        seqkit grep -w 0 -f ${upptmpdir}/tmp_result/query_ids.txt ${upptmpdir}/tmp_result/output_alignment_masked.fasta -o ${upptmpdir}/aligned/${cnt}.fa
+        witch.py -y -k 4 -A 1000 -q ${i} -b ${accessory_dir}/${dt}_ao.fasta -e ${accessory_dir}/${dt}.nwk -o output_alignment.fasta -d ${upptmpdir}/tmp_result/ -t $upp_c
+#        grep -w -A 1 -f ${upptmpdir}/xtmp_result/query_ids.txt ${upptmpdir}/tmp_result/output_alignment_masked.fasta --no-group-separator > ${upptmpdir}/aligned/${cnt}.fa
+        seqkit grep -w 0 -f ${upptmpdir}/tmp_result/query_ids.txt ${upptmpdir}/tmp_result/output_alignment.fasta.masked -o ${upptmpdir}/aligned/${cnt}.fa
         cnt=$((cnt+1))
         rm -rf ${upptmpdir}/tmp
         rm -rf ${upptmpdir}/tmp_result
@@ -143,7 +144,10 @@ if __name__ == '__main__':
   comb_json.py --indir ${tmpdir} --outfile ${tmpdir}/placement.jplace
   cp ${tmpdir}/placement.jplace ${out_dir}/
   cat ${tmpdir}/*entropy.txt > ${out_dir}/entropy.txt
-  gappa examine graft --jplace-path ${tmpdir}/placement.jplace  --out-dir ${out_dir}/ --allow-file-overwriting > /dev/null 2>&1
+#  gappa examine graft --jplace-path ${tmpdir}/placement.jplace  --out-dir ${out_dir}/ --allow-file-overwriting > /dev/null 2>&1
+  bp placement --placements  ${out_dir}/placement.jplace \
+    --output ${out_dir}/placement.nwk \
+    --method fully-resolved
   function cleanup {
     rm -rf $tmpdir
     rm -rf $upptmpdir
@@ -172,17 +176,20 @@ else
   cp ${tmpdir}/${data_type}_aligned.fa ${out_dir}/
   cat ${tmpdir}/*entropy.txt > ${out_dir}/entropy.txt
   cp ${tmpdir}/${data_type}_upp.log ${out_dir}
-  gappa examine graft --jplace-path ${tmpdir}/placement.jplace  --out-dir ${out_dir}/ --allow-file-overwriting > /dev/null 2>&1
+  bp placement --placements  ${out_dir}/placement.jplace \
+    --output ${out_dir}/placement.nwk \
+    --method fully-resolved
+#  gappa examine graft --jplace-path ${tmpdir}/placement.jplace  --out-dir ${out_dir}/ --allow-file-overwriting > /dev/null 2>&1
 fi
 
-cat ${out_dir}/*aligned.fa > ${out_dir}/aligned.fa
-count_gapped_ratio.py --infile ${out_dir}/aligned.fa --outfile ${out_dir}/gap.txt
-rm ${out_dir}/aligned.fa
-filter_by_entropy_gap.sh 0.8 0.1 ${out_dir} ${query_file} ${accessory_dir}
-filter_by_entropy_gap.sh 1 0.2 ${out_dir} ${query_file} ${accessory_dir}
-filter_by_entropy_gap.sh 1.2 0.2 ${out_dir} ${query_file} ${accessory_dir}
-filter_by_entropy_gap.sh 1.2 0.3 ${out_dir} ${query_file} ${accessory_dir}
-mkdir ${out_dir}/all
-cat ${query_file} ${accessory_dir}/seqs.fa  > ${out_dir}/all/seqs.fa
-cp ${out_dir}/placement.jplace ${out_dir}/all/
-cp ${accessory_dir}/mapfile.json ${out_dir}/all/
+#cat ${out_dir}/*aligned.fa > ${out_dir}/aligned.fa
+#count_gapped_ratio.py --infile ${out_dir}/aligned.fa --outfile ${out_dir}/gap.txt
+#rm ${out_dir}/aligned.fa
+#filter_by_entropy_gap.sh 0.8 0.1 ${out_dir} ${query_file} ${accessory_dir}
+#filter_by_entropy_gap.sh 1 0.2 ${out_dir} ${query_file} ${accessory_dir}
+#filter_by_entropy_gap.sh 1.2 0.2 ${out_dir} ${query_file} ${accessory_dir}
+#filter_by_entropy_gap.sh 1.2 0.3 ${out_dir} ${query_file} ${accessory_dir}
+#mkdir ${out_dir}/all
+#cat ${query_file} ${accessory_dir}/seqs.fa  > ${out_dir}/all/seqs.fa
+#cp ${out_dir}/placement.jplace ${out_dir}/all/
+#cp ${accessory_dir}/mapfile.json ${out_dir}/all/
